# frozen_string_literal: true

class Api::V1::Timelines::PublicController < Api::BaseController
  before_action :require_user!, only: [:show], if: :require_auth?
  after_action :insert_pagination_headers, unless: -> { @statuses.empty? }

  def show
    @statuses = load_statuses
    render json: @statuses, each_serializer: REST::StatusSerializer, relationships: StatusRelationshipsPresenter.new(@statuses, current_user&.account_id)
  end

  private

  def call_api
    #bida = URI('https://mastodon.bida.im/api/v1/timelines/public?local=true&only_media=false')
    #bida_res = Net::HTTP.get_response(bida)
    #json_bida_res=bida_res.body
    cisti = URI('https://mastodon.cisti.org/api/v1/timelines/public?local=true&only_media=false')
    cisti_res = Net::HTTP.get_response(cisti)
    json_cisti_res=cisti_res.body
    nebbia = URI('https://nebbia.fail/api/v1/timelines/public?local=true&only_media=false')
    nebbia_res = Net::HTTP.get_response(nebbia)
    json_cisti_res=cisti_res.body
    #bida_arr = JSON.parse(json_bida_res)
    cisti_arr = JSON.parse(json_cisti_res)
    nebbia_arr = JSON.parse(json_cisti_res)
    union = cisti_arr + nebbia_arr
    union.sort_by{ |e| e['created_at'] }.to_json

  end

  def require_auth?
    !Setting.timeline_preview
  end

  def load_statuses
    cached_public_statuses_page
  end

  def cached_public_statuses_page
    cache_collection(public_statuses, Status)
  end

  def public_statuses
    public_feed.get(
      limit_param(DEFAULT_STATUSES_LIMIT),
      params[:max_id],
      params[:since_id],
      params[:min_id]
    )
  end

  def public_feed
    PublicFeed.new(
      current_account,
      local: truthy_param?(:local),
      remote: truthy_param?(:remote),
      only_media: truthy_param?(:only_media)
    )
  end

  def insert_pagination_headers
    set_pagination_headers(next_path, prev_path)
  end

  def pagination_params(core_params)
    params.slice(:local, :remote, :limit, :only_media).permit(:local, :remote, :limit, :only_media).merge(core_params)
  end

  def next_path
    api_v1_timelines_public_url pagination_params(max_id: pagination_max_id)
  end

  def prev_path
    api_v1_timelines_public_url pagination_params(min_id: pagination_since_id)
  end

  def pagination_max_id
    @statuses.last.id
  end

  def pagination_since_id
    @statuses.first.id
  end
end
